==> froala-editor-1.2.2.tgz: package/Readme.md <==
#Froala WYSIWYG Editor
A beautiful jQuery WYSIWYG text editor based on HTML5 technology. Cross browser, with mobile support, high performance and Retina Ready flat design.

## Licensing

The editor can be used for free only for personal and non-profit projects under the [CC NC-ND license](http://creativecommons.org/licenses/by-nc-nd/4.0/). For commercial applications you have to purchase one of the following licenses according to your needs. You can find more about that on our website on the [pricing plan page](http://editor.froala.com/download).

1. Single Website - $49
* Developer - $79
* Business - $159
* OEM - $299

## Useful links

* Official website:  [editor.froala.com](http://editor.froala.com)
* Official download: [editor.froala.com/latest.zip](http://editor.froala.com/latest.zip)
* Official documentation:  [editor.froala.com/docs](http://editor.froala.com/docs)
* Changelog:  [editor.froala.com/changelog](http://editor.froala.com/changelog)
* Licensing: [editor.froala.com/download](http://editor.froala.com/download)
* Support: [editor.froala.com/contact](http://editor.froala.com/contact)

## Reporting issues
We use GitHub Issues as our official bug tracker. We strive to keep this a clean, maintainable and searchable record of our open and closed bugs, therefore we kindly ask you to obey some rules before reporting an issue:

1. Make sure the report is accompanied by a reproducible demo.
* Always add information on what browser it applies to, and other information needed for us to debug.
* It may be that the bug is already fixed. Try your editor with our latest work from https://github.com/froala/froala-wysiwyg/tree/master/js before reporting.
* For feature requests, tech support and general discussion, don't use GitHub Issues. See [http://editor.froala.com/contact](htp://editor.froala.com/contact) for the appropriate channels.

==> froala-editor-1.2.5.tgz: package/Readme.md <==
#Froala WYSIWYG Editor
A beautiful jQuery WYSIWYG text editor based on HTML5 technology. Cross browser, with mobile support, high performance and Retina Ready flat design.

## Licensing

The editor can be used for free only for personal and non-profit projects under the [CC NC-ND license](http://creativecommons.org/licenses/by-nc-nd/4.0/). For commercial applications you have to purchase one of the following licenses according to your needs. You can find more about that on our website on the [pricing plan page](http://editor.froala.com/download).

1. Single Website - $49
* Developer - $79
* Business - $159
* OEM - $299

## Useful links

* Official website:  [editor.froala.com](http://editor.froala.com)
* Official download: [editor.froala.com/latest.zip](http://editor.froala.com/latest.zip)
* Official documentation:  [editor.froala.com/docs](http://editor.froala.com/docs)
* Changelog:  [editor.froala.com/changelog](http://editor.froala.com/changelog)
* Licensing: [editor.froala.com/download](http://editor.froala.com/download)
* Support: [editor.froala.com/contact](http://editor.froala.com/contact)

## Reporting issues
We use GitHub Issues as our official bug tracker. We strive to keep this a clean, maintainable and searchable record of our open and closed bugs, therefore we kindly ask you to obey some rules before reporting an issue:

1. Make sure that you are using the latest version of the Froala WYSIWYG Editor. The issue that you are about to report may be already fixed with on our latest work https://github.com/froala/froala-wysiwyg/tree/master/js, so please try it before reporting.
* Always add information on what browser it applies to, and other information needed for us to debug.
* Make sure the report is accompanied by a reproducible demo.
* We are trying to fix all issues ASAP. This means a lot of work and all we are asking is for you to be polite and use appropriate language.
* DO NOT SPAM! We are reading every single issue opened. Please do not open 2 different issues for the same thing.
* For feature requests, tech support and general discussion, don't use GitHub Issues. See [http://editor.froala.com/contact](htp://editor.froala.com/contact) for the appropriate channels.
